"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import UnrecognizedStr
from typing import Literal, Union


CardScheme = Union[
    Literal[
        "accel",
        "amex",
        "bancontact",
        "carte-bancaire",
        "cirrus",
        "culiance",
        "dankort",
        "diners-club",
        "discover",
        "eftpos-australia",
        "elo",
        "hipercard",
        "jcb",
        "maestro",
        "mastercard",
        "mir",
        "nyce",
        "other",
        "pulse",
        "rupay",
        "star",
        "uatp",
        "unionpay",
        "visa",
    ],
    UnrecognizedStr,
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import UnrecognizedStr
from typing import Literal, Union


ErrorLocation = Union[
    Literal["query", "body", "path", "header", "unknown"], UnrecognizedStr
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from typing import TYPE_CHECKING
from importlib import import_module

if TYPE_CHECKING:
    from .globals import Globals, GlobalsTypedDict

__all__ = ["Globals", "GlobalsTypedDict"]

_dynamic_imports: dict[str, str] = {
    "Globals": ".globals",
    "GlobalsTypedDict": ".globals",
}


def __getattr__(attr_name: str) -> object:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(
            f"No {attr_name} found in _dynamic_imports for module name -> {__name__} "
        )

    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(
            f"Failed to import {attr_name} from {module_name}: {e}"
        ) from e
    except AttributeError as e:
        raise AttributeError(
            f"Failed to get {attr_name} from {module_name}: {e}"
        ) from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import BaseModel
from gr4vy.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Any, Dict, Literal, Optional
from typing_extensions import Annotated, TypedDict


class TransactionRetriesReportSpecTypedDict(TypedDict):
    params: Dict[str, Any]
    r"""The parameters for the transaction retries report model."""
    model: Literal["transaction_retries"]
    r"""The report model type."""


class TransactionRetriesReportSpec(BaseModel):
    params: Dict[str, Any]
    r"""The parameters for the transaction retries report model."""

    MODEL: Annotated[
        Annotated[
            Optional[Literal["transaction_retries"]],
            AfterValidator(validate_const("transaction_retries")),
        ],
        pydantic.Field(alias="model"),
    ] = "transaction_retries"
    r"""The report model type."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import UnrecognizedStr
from typing import Literal, Union


RefundStatus = Union[
    Literal["processing", "succeeded", "failed", "declined", "voided"], UnrecognizedStr
]
